require 'fileutils'

ruby_ver = case Sketchup.version.to_i
           when 24
               '32'
           when 21, 22, 23
               '27'
           when 19, 20
               '25'
           when 18, 17
               '22'
           else
               '32'
           end
file = 'rgloader' + ruby_ver
if Object::RUBY_PLATFORM =~ /darwin/i
    file += '.darwin'
    ext = '.bundle'
else
    arch = Sketchup.respond_to?(:is_64bit?) && Sketchup.is_64bit? ? '.x64' : ''
    file += '.mingw' + arch
    ext = '.so'
end

directory = File.expand_path(File.dirname(__FILE__))
full_file_path = File.join(directory, file + ext)
raise LoadError, "Could not find rgloader: " + full_file_path unless File.exist?(full_file_path)

$LOADED_FEATURES.reject!{|p| p.start_with?(full_file_path)}

loaded_file = file + '_loaded'
full_loaded_path = File.join(directory, loaded_file + ext)
if !File.exist?(full_loaded_path) || !FileUtils.compare_file(full_file_path, full_loaded_path)
    File.unlink(full_loaded_path) if File.exist?(full_loaded_path)
    FileUtils.cp(full_file_path, full_loaded_path)
end

require full_loaded_path

if !defined?(RGLoader) then 
  raise LoadError, "The RubyEncoder loader is not installed."
end
